@@ -1,10 +1,10 @@
-from typing import List
-
 import aiofiles
 import distro
 import logging
 import os
 import re
+from typing import Tuple
+
 
 log = logging.getLogger(__name__)
 
@@ -134,13 +134,8 @@ async def _get_synology_osrelease(osrelease: str) -> str:
                 return f'{synoinfo["majorversion"]}.{synoinfo["minorversion"]}-{synoinfo["buildnumber"]}'
 
 
-async def _get_osrelease_info(osrelease: str) -> List[str]:
-    osrelease_info = osrelease.split(".")
-    for idx, value in enumerate(osrelease_info):
-        if not value.isdigit():
-            continue
-        osrelease_info[idx] = int(value)
-    return osrelease_info
+async def _get_osrelease_info(osrelease: str) -> Tuple:
+    return tuple(int(x) if x.isdigit() else x for x in osrelease.split("."))
 
 
 async def _get_os(osfullname: str) -> str:
@@ -185,7 +180,7 @@ async def load_linux_distribution(hub):
         hub.corn.CORN.ps = "ps -o user,pid,ppid,tty,time,comm"
     hub.corn.CORN.osrelease_info = await _get_osrelease_info(hub.corn.CORN.osrelease)
 
-    major_version = distro.LinuxDistribution().major_version().strip("\"'")
+    major_version = info.major_version().strip("\"'")
     hub.corn.CORN.osmajorrelease = (
         int(major_version) if major_version else hub.corn.CORN.osrelease_info[0]
     )
@@ -194,7 +189,7 @@ async def load_linux_distribution(hub):
     os_name = hub.corn.CORN[
         "os"
         if hub.corn.CORN.os
-        in ("Debian", "FreeBSD", "OpenBSD", "NetBSD", "Mac", "Raspbian")
+        in ("Debian", "Raspbian")
         else "osfullname"
     ]
     finger = (
