@@ -11,7 +11,7 @@ async def load_systemd(hub):
     if cmd and shutil.which("localectl"):
         log.debug("Adding systemd corn")
         systemd_info = (
-            (await hub.exec.cmd.run([cmd, "--version"]))["stdout"].strip().splitlines()
+            (await hub.exec.cmd.run([cmd, "--version"])).stdout.strip().splitlines()
         )
         hub.corn.CORN.systemd.version = systemd_info[0].split()[1]
         hub.corn.CORN.systemd.features = systemd_info[1]
@@ -49,7 +49,7 @@ async def load_init(hub):
                                         buf = b""
                                         break
                                 edge = buf[-edge_len:]
-                                buf = fp_.read(buf_size).lower()
+                                buf = (await fp_.read(buf_size)).lower()
                     except (IOError, OSError) as exc:
                         log.error(
                             "Unable to read from init_bin (%s): %s", init_bin, exc
